@@ -1,22 +1,22 @@
 /*
-    <one line to give the program's name and a brief idea of what it does.>
-    Copyright (C) 2013  <copyright holder> <email>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-*/
-
+ * LXImage-Qt - a simple and fast image viewer
+ * Copyright (C) 2013  PCMan <pcman.tw@gmail.com>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ */
 
 #ifndef LXIMAGE_IMAGEVIEW_H
 #define LXIMAGE_IMAGEVIEW_H
@@ -41,9 +41,9 @@ public:
   ImageView(QWidget* parent = 0);
   virtual ~ImageView();
 
-  void setImage(QImage image, bool show = true);
-  void setGifAnimation(QString fileName);
-  void setSVG(QString fileName);
+  void setImage(const QImage& image, bool show = true);
+  void setGifAnimation(const QString& fileName);
+  void setSVG(const QString& fileName);
 
   QImage image() {
     return image_;
@@ -72,6 +72,16 @@ public:
   // if set to true, hides the cursor after 3s of inactivity
   void hideCursor(bool enable);
 
+  // Annotation tools
+  enum Tool {
+    ToolNone,
+    ToolArrow,
+    ToolRectangle,
+    ToolCircle,
+    ToolNumber
+  };
+  void activateTool(Tool tool);
+
 Q_SIGNALS:
   void fileDropped(const QString file);
 
@@ -90,6 +100,12 @@ private:
   QRect viewportToScene(const QRect& rect);
   QRect sceneToViewport(const QRectF& rect);
 
+  void drawArrow(QPainter &painter,
+                 const QPoint &start,
+                 const QPoint &end,
+                 qreal tipAngle,
+                 int tipLen) const;
+
 private Q_SLOTS:
   void onFileDropped(const QString file);
   void generateCache();
@@ -108,6 +124,9 @@ private:
   double scaleFactor_;
   bool autoZoomFit_;
   bool isSVG; // is the image an SVG file?
+  Tool currentTool; // currently selected tool
+  QPoint startPoint; // starting point for the tool
+  int nextNumber;
 };
 
 }
