@@ -4,322 +4,527 @@
 <context>
     <name>LxImage::Application</name>
     <message>
-        <location filename="../application.cpp" line="87"/>
+        <location filename="../application.cpp" line="94"/>
         <source>Take a screenshot</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../application.cpp" line="91"/>
+        <location filename="../application.cpp" line="98"/>
         <source>[FILE1, FILE2,...]</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>LxImage::ImageShackUpload</name>
+    <message>
+        <location filename="../upload/imageshackupload.cpp" line="50"/>
+        <source>unknown error response</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LxImage::ImgBBUpload</name>
+    <message>
+        <location filename="../upload/imgbbupload.cpp" line="44"/>
+        <source>unknown error response</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LxImage::ImgurUpload</name>
+    <message>
+        <location filename="../upload/imgurupload.cpp" line="47"/>
+        <source>unknown error response</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>LxImage::MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="147"/>
+        <location filename="../mainwindow.cpp" line="164"/>
         <source>About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="148"/>
-        <source>LXImage - a simple and fast image viewer
+        <location filename="../mainwindow.cpp" line="165"/>
+        <source>LXImage-Qt - a simple and fast image viewer
 
 Copyright (C) 2013
-LXDE Project: http://lxde.org/
+LXQt Project: https://lxqt.org/
 
 Authors:
 Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="241"/>
+        <location filename="../mainwindow.cpp" line="295"/>
         <source>Open File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="242"/>
-        <location filename="../mainwindow.cpp" line="263"/>
+        <location filename="../mainwindow.cpp" line="296"/>
+        <location filename="../mainwindow.cpp" line="324"/>
         <source>Image files (%1)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="263"/>
+        <location filename="../mainwindow.cpp" line="302"/>
+        <source>Open directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="323"/>
         <source>Save File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="525"/>
-        <source>%1 (Loading...) - Image Viewer</source>
+        <location filename="../mainwindow.cpp" line="598"/>
+        <source>[*]%1 (Loading...) - Image Viewer</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="530"/>
-        <source>%1 (Failed to Load) - Image Viewer</source>
+        <location filename="../mainwindow.cpp" line="603"/>
+        <source>[*]%1 (Failed to Load) - Image Viewer</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="534"/>
-        <source>%1 (%2x%3) - Image Viewer</source>
+        <location filename="../mainwindow.cpp" line="607"/>
+        <source>[*]%1 (%2x%3) - Image Viewer</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="544"/>
-        <source>Image Viewer</source>
+        <location filename="../mainwindow.cpp" line="643"/>
+        <source>[*]Image Viewer</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="719"/>
+        <location filename="../mainwindow.cpp" line="918"/>
         <source>Thumbnails</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="966"/>
+        <source>EXIF Data</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LxImage::MruMenu</name>
+    <message>
+        <location filename="../mrumenu.cpp" line="45"/>
+        <source>&amp;Clear</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LxImage::UploadDialog</name>
+    <message>
+        <location filename="../upload/uploaddialog.cpp" line="52"/>
+        <source>Imgur</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../upload/uploaddialog.cpp" line="53"/>
+        <source>ImgBB</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../upload/uploaddialog.cpp" line="54"/>
+        <source>ImageShack</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../upload/uploaddialog.cpp" line="137"/>
+        <source>Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../upload/uploaddialog.cpp" line="140"/>
+        <source>Stop</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../upload/uploaddialog.cpp" line="143"/>
+        <source>Close</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../upload/uploaddialog.cpp" line="150"/>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="412"/>
+        <location filename="../mainwindow.ui" line="14"/>
         <source>Image Viewer</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="413"/>
+        <location filename="../mainwindow.ui" line="195"/>
         <source>&amp;About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="414"/>
+        <location filename="../mainwindow.ui" line="204"/>
         <source>&amp;Open File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="415"/>
+        <location filename="../mainwindow.ui" line="207"/>
         <source>Ctrl+O</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="416"/>
+        <location filename="../mainwindow.ui" line="228"/>
         <source>&amp;Save</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="417"/>
+        <location filename="../mainwindow.ui" line="231"/>
         <source>Ctrl+S</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="418"/>
+        <location filename="../mainwindow.ui" line="240"/>
         <source>Save &amp;As</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="419"/>
+        <location filename="../mainwindow.ui" line="243"/>
         <source>Ctrl+A</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="420"/>
+        <location filename="../mainwindow.ui" line="252"/>
         <source>&amp;Close</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="421"/>
+        <location filename="../mainwindow.ui" line="255"/>
         <source>Ctrl+W</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="422"/>
+        <location filename="../mainwindow.ui" line="264"/>
         <source>Zoom &amp;In</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="423"/>
-        <source>Ctrl++</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="424"/>
+        <location filename="../mainwindow.ui" line="276"/>
         <source>Zoom &amp;Out</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="425"/>
+        <location filename="../mainwindow.ui" line="279"/>
         <source>Ctrl+-</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="426"/>
+        <location filename="../mainwindow.ui" line="288"/>
         <source>&amp;Copy to Clipboard</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="427"/>
-        <location filename="../../build/src/ui_mainwindow.h" line="429"/>
+        <location filename="../mainwindow.ui" line="297"/>
+        <location filename="../mainwindow.ui" line="300"/>
         <source>Next File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="432"/>
-        <location filename="../../build/src/ui_mainwindow.h" line="434"/>
+        <location filename="../mainwindow.ui" line="312"/>
+        <location filename="../mainwindow.ui" line="315"/>
         <source>Previous File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="431"/>
+        <location filename="../mainwindow.ui" line="303"/>
         <source>PgDown</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="436"/>
+        <location filename="../mainwindow.ui" line="67"/>
+        <source>&amp;Recently Opened Files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="175"/>
+        <source>toolBar_2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="216"/>
+        <source>&amp;Reload File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="219"/>
+        <source>Ctrl+R</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="267"/>
+        <source>Ctrl+=</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="318"/>
         <source>PgUp</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="437"/>
+        <location filename="../mainwindow.ui" line="327"/>
         <source>Original Size</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="438"/>
+        <location filename="../mainwindow.ui" line="330"/>
+        <source>Ctrl+0</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="339"/>
         <source>&amp;Fit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="439"/>
+        <location filename="../mainwindow.ui" line="348"/>
         <source>&amp;Rotate Clockwise</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="440"/>
+        <location filename="../mainwindow.ui" line="351"/>
+        <source>R</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="360"/>
         <source>Rotate &amp;Counterclockwise</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="441"/>
+        <location filename="../mainwindow.ui" line="363"/>
+        <source>L</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="368"/>
         <source>P&amp;references</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="442"/>
+        <location filename="../mainwindow.ui" line="373"/>
         <source>&amp;Print</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="443"/>
+        <location filename="../mainwindow.ui" line="376"/>
         <source>Ctrl+P</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="444"/>
+        <location filename="../mainwindow.ui" line="385"/>
         <source>First File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="445"/>
+        <location filename="../mainwindow.ui" line="388"/>
         <source>Home</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="446"/>
+        <location filename="../mainwindow.ui" line="397"/>
         <source>Last File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="447"/>
+        <location filename="../mainwindow.ui" line="400"/>
         <source>End</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="448"/>
+        <location filename="../mainwindow.ui" line="409"/>
         <source>&amp;New Window</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="449"/>
+        <location filename="../mainwindow.ui" line="412"/>
         <source>Ctrl+N</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="450"/>
+        <location filename="../mainwindow.ui" line="417"/>
         <source>Flip &amp;Horizontally</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="451"/>
+        <location filename="../mainwindow.ui" line="420"/>
+        <source>H</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="429"/>
         <source>Capture Screenshot</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="452"/>
+        <location filename="../mainwindow.ui" line="437"/>
         <source>F&amp;ull Screen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="453"/>
+        <location filename="../mainwindow.ui" line="440"/>
         <source>F11</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="454"/>
+        <location filename="../mainwindow.ui" line="445"/>
         <source>Flip &amp;Vertically</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="455"/>
+        <location filename="../mainwindow.ui" line="448"/>
+        <source>V</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="457"/>
         <source>&amp;Paste from Clipboard</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="456"/>
+        <location filename="../mainwindow.ui" line="469"/>
         <source>&amp;Slide Show</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="457"/>
+        <location filename="../mainwindow.ui" line="478"/>
         <source>&amp;Delete</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="458"/>
+        <location filename="../mainwindow.ui" line="481"/>
         <source>Del</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="459"/>
+        <location filename="../mainwindow.ui" line="489"/>
         <source>Show Thumbnails</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="460"/>
+        <location filename="../mainwindow.ui" line="492"/>
+        <source>T</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="497"/>
         <source>File Properties</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="461"/>
+        <location filename="../mainwindow.ui" line="506"/>
+        <source>Open &amp;Directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="509"/>
+        <source>Ctrl+D</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="518"/>
+        <source>Upload</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="521"/>
+        <source>Upload the image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="529"/>
+        <source>Show EXIF Data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="541"/>
+        <source>No Tool</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="544"/>
+        <source>Deselect all drawing tools</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="556"/>
+        <source>Draw Arrow</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="559"/>
+        <source>Draw an arrow</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="571"/>
+        <source>Draw Rectangle</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="574"/>
+        <source>Draw a hollow rectangle</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="586"/>
+        <source>Draw Circle</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="589"/>
+        <source>Draw a hollow circle</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="601"/>
+        <source>Draw Number</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="604"/>
+        <source>Draw incrementing numbers</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="63"/>
         <source>&amp;File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="462"/>
+        <location filename="../mainwindow.ui" line="87"/>
         <source>&amp;Help</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="463"/>
+        <location filename="../mainwindow.ui" line="93"/>
         <source>Go</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="464"/>
+        <location filename="../mainwindow.ui" line="102"/>
         <source>&amp;View</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="465"/>
+        <location filename="../mainwindow.ui" line="118"/>
         <source>&amp;Edit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_mainwindow.h" line="466"/>
+        <location filename="../mainwindow.ui" line="140"/>
         <source>Toolbar</source>
         <translation type="unfinished"></translation>
     </message>
@@ -327,32 +532,32 @@ Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
 <context>
     <name>PreferencesDialog</name>
     <message>
-        <location filename="../../build/src/ui_preferencesdialog.h" line="126"/>
+        <location filename="../preferencesdialog.ui" line="14"/>
         <source>Preferences</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_preferencesdialog.h" line="127"/>
+        <location filename="../preferencesdialog.ui" line="33"/>
         <source>Icon theme:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_preferencesdialog.h" line="128"/>
+        <location filename="../preferencesdialog.ui" line="43"/>
         <source>Normal background color:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_preferencesdialog.h" line="129"/>
+        <location filename="../preferencesdialog.ui" line="50"/>
         <source>Fullscreen background color:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_preferencesdialog.h" line="132"/>
+        <location filename="../preferencesdialog.ui" line="71"/>
         <source>Slide show interval (seconds):</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_preferencesdialog.h" line="133"/>
+        <location filename="../preferencesdialog.ui" line="24"/>
         <source>General</source>
         <translation type="unfinished"></translation>
     </message>
@@ -360,49 +565,67 @@ Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
 <context>
     <name>ScreenshotDialog</name>
     <message>
-        <location filename="../../build/src/ui_screenshotdialog.h" line="123"/>
+        <location filename="../screenshotdialog.ui" line="14"/>
         <source>Screenshot</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_screenshotdialog.h" line="124"/>
+        <location filename="../screenshotdialog.ui" line="27"/>
         <source>Take a screenshot</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_screenshotdialog.h" line="125"/>
+        <location filename="../screenshotdialog.ui" line="34"/>
         <source>Region</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_screenshotdialog.h" line="126"/>
+        <location filename="../screenshotdialog.ui" line="40"/>
         <source>Whole screen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_screenshotdialog.h" line="127"/>
+        <location filename="../screenshotdialog.ui" line="50"/>
         <source>Current window only</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_screenshotdialog.h" line="128"/>
+        <location filename="../screenshotdialog.ui" line="57"/>
+        <source>Capture an area of the screen</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../screenshotdialog.ui" line="67"/>
         <source>Include mouse cursor</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_screenshotdialog.h" line="129"/>
+        <location filename="../screenshotdialog.ui" line="74"/>
         <source> seconds</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_screenshotdialog.h" line="130"/>
+        <location filename="../screenshotdialog.ui" line="91"/>
         <source>Delay:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_screenshotdialog.h" line="131"/>
+        <location filename="../screenshotdialog.ui" line="101"/>
         <source>Include window title and frame</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>UploadDialog</name>
+    <message>
+        <location filename="../upload/uploaddialog.ui" line="14"/>
+        <source>Upload</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../upload/uploaddialog.ui" line="39"/>
+        <source>Copy</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
