@@ -1,456 +1,563 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1">
-<context>
-    <name>../data/lxinput.desktop.in.h:1</name>
-    <message>
-        <source>Keyboard and Mouse</source>
-        <translation type="obsolete">Tangentbord och mus</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.desktop.in.h:2</name>
-    <message>
-        <source>Configure keyboard, mouse, and other input devices</source>
-        <translation type="obsolete">Inställningar för tangentbord, mus och andra inmatningsenheter</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:1</name>
-    <message>
-        <source>Input Device Preferences</source>
-        <translation type="obsolete">Egenskaper för inmatningsenhet</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:10</name>
-    <message>
-        <source>Mouse</source>
-        <translation type="obsolete">Mus</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:11</name>
-    <message>
-        <source>Delay before each key starts repeating</source>
-        <translation type="obsolete">Tid innan varje tangent repeteras</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:12</name>
-    <message>
-        <source>Repeat delay:</source>
-        <translation type="obsolete">Tid innan upprepning:</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:13</name>
-    <message>
-        <source>Interval between each key repeat</source>
-        <translation type="obsolete">Intervall mellan upprening av tangenter</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:14</name>
-    <message>
-        <source>Long</source>
-        <translation type="obsolete">Lång</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:15</name>
-    <message>
-        <source>Short</source>
-        <translation type="obsolete">Kort</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:16</name>
-    <message>
-        <source>Repeat interval:</source>
-        <translation type="obsolete">Tid mellan upprepningar:</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:17</name>
-    <message>
-        <source>Type in the following box to test your keyboard settings</source>
-        <translation type="obsolete">För att pröva dina inställningar kan du skriva i följande ruta</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:18</name>
-    <message>
-        <source>&lt;b&gt;Character Repeat&lt;/b&gt;</source>
-        <translation type="obsolete">&lt;b&gt;Teckenupprepning&lt;/b&gt;</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:19</name>
-    <message>
-        <source>Beep when there is an error of keyboard input</source>
-        <translation type="obsolete">Avge ett pip när ett fel uppstår vid tangentbordsinmatning</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:2</name>
-    <message>
-        <source>Sensitivity:</source>
-        <translation type="obsolete">Känslighet:</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:20</name>
-    <message>
-        <source>&lt;b&gt;Keyboard layout&lt;/b&gt;</source>
-        <translation type="obsolete">&lt;b&gt;Tangentbordsupplägg&lt;/b&gt;</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:21</name>
-    <message>
-        <source>Keyboard</source>
-        <translation type="obsolete">Tangentbord</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:22</name>
-    <message>
-        <source>Touch Pad</source>
-        <translation type="obsolete">Pekplatta</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:3</name>
-    <message>
-        <source>High</source>
-        <translation type="obsolete">Hög</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:4</name>
-    <message>
-        <source>Low</source>
-        <translation type="obsolete">Låg</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:5</name>
-    <message>
-        <source>Fast</source>
-        <translation type="obsolete">Snabb</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:6</name>
-    <message>
-        <source>Slow</source>
-        <translation type="obsolete">Långsam</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:7</name>
-    <message>
-        <source>Acceleration:</source>
-        <translation type="obsolete">Acceleration:</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:8</name>
-    <message>
-        <source>&lt;b&gt;Motion&lt;/b&gt;</source>
-        <translation type="obsolete">&lt;b&gt;Förflyttning&lt;/b&gt;</translation>
-    </message>
-</context>
-<context>
-    <name>../data/lxinput.ui.h:9</name>
-    <message>
-        <source>Left handed (Swap left and right mouse buttons)</source>
-        <translation type="obsolete">Vänsterhänt (byt funktioner för vänster och höger musknapp)</translation>
-    </message>
-</context>
+<TS version="2.1" language="sv">
 <context>
     <name>LxImage::Application</name>
     <message>
+        <location filename="../application.cpp" line="94"/>
         <source>Take a screenshot</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../application.cpp" line="98"/>
         <source>[FILE1, FILE2,...]</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>LxImage::ImageShackUpload</name>
+    <message>
+        <location filename="../upload/imageshackupload.cpp" line="50"/>
+        <source>unknown error response</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LxImage::ImgBBUpload</name>
+    <message>
+        <location filename="../upload/imgbbupload.cpp" line="44"/>
+        <source>unknown error response</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LxImage::ImgurUpload</name>
+    <message>
+        <location filename="../upload/imgurupload.cpp" line="47"/>
+        <source>unknown error response</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>LxImage::MainWindow</name>
     <message>
+        <location filename="../mainwindow.cpp" line="164"/>
         <source>About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>LXImage - a simple and fast image viewer
+        <location filename="../mainwindow.cpp" line="295"/>
+        <source>Open File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="296"/>
+        <location filename="../mainwindow.cpp" line="324"/>
+        <source>Image files (%1)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="323"/>
+        <source>Save File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="918"/>
+        <source>Thumbnails</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="966"/>
+        <source>EXIF Data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="598"/>
+        <source>[*]%1 (Loading...) - Image Viewer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="603"/>
+        <source>[*]%1 (Failed to Load) - Image Viewer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="607"/>
+        <source>[*]%1 (%2x%3) - Image Viewer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="643"/>
+        <source>[*]Image Viewer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="302"/>
+        <source>Open directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="165"/>
+        <source>LXImage-Qt - a simple and fast image viewer
 
 Copyright (C) 2013
-LXDE Project: http://lxde.org/
+LXQt Project: https://lxqt.org/
 
 Authors:
 Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
         <translation type="unfinished"></translation>
     </message>
+</context>
+<context>
+    <name>LxImage::MruMenu</name>
     <message>
-        <source>Open File</source>
+        <location filename="../mrumenu.cpp" line="45"/>
+        <source>&amp;Clear</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LxImage::UploadDialog</name>
+    <message>
+        <location filename="../upload/uploaddialog.cpp" line="52"/>
+        <source>Imgur</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Image files (%1)</source>
+        <location filename="../upload/uploaddialog.cpp" line="53"/>
+        <source>ImgBB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Save File</source>
+        <location filename="../upload/uploaddialog.cpp" line="54"/>
+        <source>ImageShack</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>%1 (Loading...) - Image Viewer</source>
+        <location filename="../upload/uploaddialog.cpp" line="137"/>
+        <source>Start</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>%1 (Failed to Load) - Image Viewer</source>
+        <location filename="../upload/uploaddialog.cpp" line="140"/>
+        <source>Stop</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>%1 (%2x%3) - Image Viewer</source>
+        <location filename="../upload/uploaddialog.cpp" line="143"/>
+        <source>Close</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Image Viewer</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Thumbnails</source>
+        <location filename="../upload/uploaddialog.cpp" line="150"/>
+        <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
+        <location filename="../mainwindow.ui" line="14"/>
         <source>Image Viewer</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="67"/>
+        <source>&amp;Recently Opened Files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="175"/>
+        <source>toolBar_2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="195"/>
         <source>&amp;About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="204"/>
         <source>&amp;Open File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="207"/>
         <source>Ctrl+O</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="216"/>
+        <source>&amp;Reload File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="219"/>
+        <source>Ctrl+R</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="228"/>
         <source>&amp;Save</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="231"/>
         <source>Ctrl+S</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="240"/>
         <source>Save &amp;As</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="243"/>
         <source>Ctrl+A</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="252"/>
         <source>&amp;Close</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="255"/>
         <source>Ctrl+W</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="264"/>
         <source>Zoom &amp;In</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Ctrl++</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
+        <location filename="../mainwindow.ui" line="276"/>
         <source>Zoom &amp;Out</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="279"/>
         <source>Ctrl+-</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="288"/>
         <source>&amp;Copy to Clipboard</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="297"/>
+        <location filename="../mainwindow.ui" line="300"/>
         <source>Next File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="312"/>
+        <location filename="../mainwindow.ui" line="315"/>
         <source>Previous File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="327"/>
         <source>Original Size</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="339"/>
         <source>&amp;Fit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="348"/>
         <source>&amp;Rotate Clockwise</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="351"/>
+        <source>R</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="360"/>
         <source>Rotate &amp;Counterclockwise</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="363"/>
+        <source>L</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="368"/>
         <source>P&amp;references</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="373"/>
         <source>&amp;Print</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="385"/>
         <source>First File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="388"/>
         <source>Home</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="397"/>
         <source>Last File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="400"/>
         <source>End</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="409"/>
         <source>&amp;New Window</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="412"/>
         <source>Ctrl+N</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="417"/>
         <source>Flip &amp;Horizontally</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="420"/>
+        <source>H</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="429"/>
         <source>Capture Screenshot</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="437"/>
         <source>F&amp;ull Screen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="440"/>
         <source>F11</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="445"/>
         <source>Flip &amp;Vertically</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="448"/>
+        <source>V</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="457"/>
         <source>&amp;Paste from Clipboard</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="469"/>
         <source>&amp;Slide Show</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="478"/>
         <source>&amp;Delete</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="481"/>
         <source>Del</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="529"/>
+        <source>Show EXIF Data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="541"/>
+        <source>No Tool</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="544"/>
+        <source>Deselect all drawing tools</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="556"/>
+        <source>Draw Arrow</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="559"/>
+        <source>Draw an arrow</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="571"/>
+        <source>Draw Rectangle</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="574"/>
+        <source>Draw a hollow rectangle</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="586"/>
+        <source>Draw Circle</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="589"/>
+        <source>Draw a hollow circle</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="601"/>
+        <source>Draw Number</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="604"/>
+        <source>Draw incrementing numbers</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="63"/>
         <source>&amp;File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="87"/>
         <source>&amp;Help</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="93"/>
         <source>Go</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="102"/>
         <source>&amp;View</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="118"/>
         <source>&amp;Edit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="140"/>
         <source>Toolbar</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="303"/>
         <source>PgDown</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="318"/>
         <source>PgUp</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="376"/>
         <source>Ctrl+P</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="489"/>
         <source>Show Thumbnails</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../mainwindow.ui" line="492"/>
+        <source>T</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="497"/>
         <source>File Properties</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../mainwindow.ui" line="267"/>
+        <source>Ctrl+=</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="330"/>
+        <source>Ctrl+0</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="506"/>
+        <source>Open &amp;Directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="509"/>
+        <source>Ctrl+D</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="518"/>
+        <source>Upload</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="521"/>
+        <source>Upload the image</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PreferencesDialog</name>
     <message>
+        <location filename="../preferencesdialog.ui" line="14"/>
         <source>Preferences</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../preferencesdialog.ui" line="33"/>
         <source>Icon theme:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../preferencesdialog.ui" line="43"/>
         <source>Normal background color:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../preferencesdialog.ui" line="50"/>
         <source>Fullscreen background color:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../preferencesdialog.ui" line="71"/>
         <source>Slide show interval (seconds):</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../preferencesdialog.ui" line="24"/>
         <source>General</source>
         <translation type="unfinished"></translation>
     </message>
@@ -458,40 +565,67 @@ Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
 <context>
     <name>ScreenshotDialog</name>
     <message>
+        <location filename="../screenshotdialog.ui" line="14"/>
         <source>Screenshot</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../screenshotdialog.ui" line="27"/>
         <source>Take a screenshot</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../screenshotdialog.ui" line="34"/>
         <source>Region</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../screenshotdialog.ui" line="40"/>
         <source>Whole screen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../screenshotdialog.ui" line="50"/>
         <source>Current window only</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../screenshotdialog.ui" line="67"/>
         <source>Include mouse cursor</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../screenshotdialog.ui" line="74"/>
         <source> seconds</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../screenshotdialog.ui" line="91"/>
         <source>Delay:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../screenshotdialog.ui" line="101"/>
         <source>Include window title and frame</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../screenshotdialog.ui" line="57"/>
+        <source>Capture an area of the screen</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>UploadDialog</name>
+    <message>
+        <location filename="../upload/uploaddialog.ui" line="14"/>
+        <source>Upload</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../upload/uploaddialog.ui" line="39"/>
+        <source>Copy</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
